summaryrefslogtreecommitdiff
path: root/users/timmy/default.nix
diff options
context:
space:
mode:
authorTim Keller <tjk@tjkeller.xyz>2026-06-18 21:40:11 -0500
committerTim Keller <tjk@tjkeller.xyz>2026-06-18 21:40:11 -0500
commit1996d32bef8a2d4454e680fb2d559d436e35b275 (patch)
treef42719bb08cd144576f9057c5f1cc378f0e59140 /users/timmy/default.nix
parent55767854e13dfe5e26311f222e3d713cf11ac3b3 (diff)
downloadnixos-1996d32bef8a2d4454e680fb2d559d436e35b275.tar.xz
nixos-1996d32bef8a2d4454e680fb2d559d436e35b275.zip
polkit options fixed up and nopass by default
Diffstat (limited to 'users/timmy/default.nix')
-rw-r--r--users/timmy/default.nix5
1 files changed, 4 insertions, 1 deletions
diff --git a/users/timmy/default.nix b/users/timmy/default.nix
index cb8eb7b..c38cbb7 100644
--- a/users/timmy/default.nix
+++ b/users/timmy/default.nix
@@ -55,7 +55,7 @@ in {
];
};
# Enable sudo and doas
security.sudo = {
enable = true;
wheelNeedsPassword = false;
@@ -65,6 +65,9 @@ in {
wheelNeedsPassword = false;
extraRules = [{ keepEnv = true; }];
};
+ security.polkit = {
+ _wheelNoPass = true;
+ };
# Configure automatic login with getty
services.getty = lib.mkIf cfg.autologin.enable {
@@ -55,7 +55,7 @@ in {
];
};
- # Enable sudo and doas
+ # Enable sudo, doas, polkit nopass
security.sudo = {
enable = true;